@@ -1,4 +1,5 @@
 #include "wloutput_interface.h"
+
 #include <QDebug>
 #include <QtDBus/QDBusMessage>
 #include <outputdevice.h>
@@ -7,8 +8,12 @@
 #include <QJsonDocument>
 #include <QJsonParseError>
 #include <QDBusInterface>
+
+#include <DConfig>
+
 #include <event_queue.h>
 #include <plasmawindowmanagement.h>
+
 #include "plasma_window_interface.h"
 #include "window_manager_interface.h"
 #include "wldpms_manager_interface.h"
@@ -263,6 +268,7 @@ static const float blackbodyColor[] = {
     0.62774186, 0.75306977, 1.00000000, /* 25000K */
     0.62740336, 0.75282962, 1.00000000};
 
+DCORE_USE_NAMESPACE
 wloutput_interface::wloutput_interface(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
@@ -740,7 +746,16 @@ void wloutput_interface::SetBrightness(QString uuid, const int brightness)
     if (itFind != uuid2OutputDevice.end())
     {
         auto dev = itFind.value();
-        setColorCurvesBrightness(dev, brightness / 100.0);
+
+        // 部分机型设置亮度的方式不一样，这里允许通过配置选择不同的调节方式
+        auto config = DConfig::create("org.deepin.dde.wloutput.daemon", "org.deepin.dde.wloutput.daemon");
+        if (config->isValid() && config->keyList().contains("brightnessAdjustType") && config->value("brightnessAdjustType").toString() == "colorcurve") {
+            setColorCurvesBrightness(dev, brightness / 100.0);
+        } else {
+            m_pConf->setBrightness(dev, brightness);
+            m_pConf->apply();
+        }
+        config->deleteLater();
     } else {
         qDebug() << "uuid is not found";
     }
